/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import java.awt.image.DataBuffer;
import java.text.ParseException;

/**
 * I am the type of an element in the data of a CBF image.
 */
public enum CbfElementType {
/* @formatter:off */
  UNSIGNED_8_BIT_INTEGER( "unsigned 8-bit integer",  false),
  SIGNED_8_BIT_INTEGER(   "signed 8-bit integer",    true),
  UNSIGNED_16_BIT_INTEGER("unsigned 16-bit integer", false),
  SIGNED_16_BIT_INTEGER(  "signed 16-bit integer",   true),
  UNSIGNED_32_BIT_INTEGER("unsigned 32-bit integer", false),
  SIGNED_32_BIT_INTEGER(  "signed 32-bit integer",   true),
  SIGNED_32_BIT_REAL_IEEE("signed 32-bit real IEEE", true),
  SIGNED_64_BIT_REAL_IEEE("signed 64-bit real IEEE", true);
/* @formatter:on */

  private String xBinaryElementType;
  private boolean signed;

  CbfElementType(String xBinaryElementType, boolean signed) {
    this.xBinaryElementType = xBinaryElementType;
    this.signed = signed;
  }

  public String toXBinaryElementType() {
    return xBinaryElementType;
  }

  public boolean isSigned() {
    return signed;
  }

  public static CbfElementType parse(String xBinaryElementType) throws ParseException {
    String trimmed = xBinaryElementType.trim();
    for (CbfElementType each : values())
      if (each.toXBinaryElementType().equals(trimmed)) return each;
    throw new ParseException("Unsupported type: " + trimmed, 0);
  }

  public static CbfElementType fromDataBufferType(int dataBufferType) {
    switch (dataBufferType) {
      case DataBuffer.TYPE_BYTE:
        return UNSIGNED_8_BIT_INTEGER;
      case DataBuffer.TYPE_USHORT:
        return UNSIGNED_16_BIT_INTEGER;
      case DataBuffer.TYPE_SHORT:
        return SIGNED_16_BIT_INTEGER;
      case DataBuffer.TYPE_INT:
        return SIGNED_32_BIT_INTEGER;
      case DataBuffer.TYPE_FLOAT:
        return SIGNED_32_BIT_REAL_IEEE;
      case DataBuffer.TYPE_DOUBLE:
        return SIGNED_64_BIT_REAL_IEEE;
      default:
        return SIGNED_32_BIT_INTEGER;
    }
  }
}