/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import java.io.IOException;
import java.nio.ByteOrder;

import javax.imageio.stream.ImageInputStream;

/**
 * I am a <code>CbfData</code> backed by an <code>ImageInputStream</code>.
 */
public class ImageInputStreamCbfData implements CbfData {
  private ImageInputStream stream;

  public ImageInputStreamCbfData(ImageInputStream stream) {
    this.stream = stream;
  }

  @Override
  public void order(ByteOrder bo) {
    stream.setByteOrder(bo);
  }

  @Override
  public byte getByte() throws IOException {
    return stream.readByte();
  }

  @Override
  public short getUbyte() throws IOException {
    return (short)stream.readUnsignedByte();
  }

  @Override
  public short getShort() throws IOException {
    return stream.readShort();
  }

  @Override
  public int getUshort() throws IOException {
    return stream.readUnsignedShort();
  }

  @Override
  public int getInt() throws IOException {
    return stream.readInt();
  }

  @Override
  public long getUint() throws IOException {
    return stream.readUnsignedInt();
  }

  @Override
  public long getLong() throws IOException {
    return stream.readLong();
  }

  @Override
  public float getFloat() throws IOException {
    return stream.readFloat();
  }

  @Override
  public double getDouble() throws IOException {
    return stream.readDouble();
  }

  @Override
  public void skipBytes(int count) throws IOException {
    stream.skipBytes(count);
  }
}
