/*
 * Copyright (c) 2011 J. Lewis Muir <jlmuir@imca.aps.anl.gov>
 *
 * Permission to use, copy, modify, and distribute this software for any
 * purpose with or without fee is hereby granted, provided that the above
 * copyright notice and this permission notice appear in all copies.
 *
 * THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
 * WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
 * ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
 * WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
 * ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
 * OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
 */

package ch.psi.imagej.cbf;

import static org.junit.Assert.assertFalse;
import static org.junit.Assert.assertTrue;

import java.io.IOException;

import javax.imageio.stream.ImageInputStream;

import org.junit.Test;

import ch.psi.imagej.cbf.CbfImageReaderSpi;

/**
 * I test <code>CbfImageReaderSpi</code>.
 */
public class CbfImageReaderSpiTest extends TestUtils {
  @Test
  public void testCanDecodeInput01() throws IOException {
    CbfImageReaderSpi spi = new CbfImageReaderSpi();
    String input = "###CBF: VERSION";
    ImageInputStream stream = streamFromString(input);
    assertTrue(spi.canDecodeInput(stream));
  }

  @Test
  public void testCanDecodeInput02() throws IOException {
    CbfImageReaderSpi spi = new CbfImageReaderSpi();
    String input = "###CBF: VERSION 1.5, CBFlib v0.7.8 - SLS/DECTRIS PILATUS detectors";
    ImageInputStream stream = streamFromString(input);
    assertTrue(spi.canDecodeInput(stream));
  }

  @Test
  public void testCanDecodeInput03() throws IOException {
    CbfImageReaderSpi spi = new CbfImageReaderSpi();
    String input =
      "###CBF: VERSION 1.5, CBFlib v0.7.8 - SLS/DECTRIS PILATUS detectors\n" +
        "\n" +
        "data_thaumatin_0001\n";
    ImageInputStream stream = streamFromString(input);
    assertTrue(spi.canDecodeInput(stream));
  }

  @Test
  public void testCanDecodeInput04() throws IOException {
    CbfImageReaderSpi spi = new CbfImageReaderSpi();
    String input =
      "###CBF: VERSIO";
    ImageInputStream stream = streamFromString(input);
    assertFalse(spi.canDecodeInput(stream));
  }

  @Test
  public void testCanDecodeInput05() throws IOException {
    CbfImageReaderSpi spi = new CbfImageReaderSpi();
    String input = "###CBF: VERSION";
    assertFalse(spi.canDecodeInput(input));
  }
}
